@@ -32,12 +32,37 @@ class Distributions:
         self.working_set = pkg_resources.WorkingSet()
 
     def query_activated(self, dist):
-        """Return True if distribution is active"""
+        """
+        Return True if distribution is active
+        Return Falsee if distribution is non-active
+
+        @param dist: pkg_resources Distribution object
+
+        @returns: True or False
+        
+        """
         if dist in self.working_set:
             return True
+        else:
+            return False
 
     def get_distributions(self, show, pkg_name="", version=""):
-        """List installed packages"""
+        """
+        Yield installed packages
+
+        @param show: Type of package(s) to show; active, non-active or all
+        @type show: string: "active", "non-active", "all"
+
+        @param pkg_name: PyPI project name
+        @type pkg_name: string
+
+        @param version: project's PyPI version
+        @type version: string
+
+        @returns: yields tuples of distribution and True or False depending
+                  on active state. e.g. (dist, True)
+        
+        """
         #pylint: disable-msg=W0612
         #'name' is a placeholder for the sorted list
         for name, dist in self.get_alpha(show, pkg_name, version):
@@ -52,7 +77,20 @@ class Distributions:
                         yield (dist, self.query_activated(dist))
 
     def get_alpha(self, show, pkg_name="", version=""):
-        """Return list of alphabetized packages"""
+        """
+        Return list of alphabetized packages
+        
+        @param pkg_name: PyPI project name
+        @type pkg_name: string
+
+        @param version: project's PyPI version
+        @type version: string
+
+        @returns: Alphabetized list of tuples. Each tuple contains
+                  a string and a pkg_resources Distribution object. 
+                  The string is the project name + version.
+        
+        """
         alpha_list = []
         for dist in self.get_packages(show):
             if pkg_name and dist.project_name != pkg_name:
@@ -67,7 +105,15 @@ class Distributions:
         return alpha_list
     
     def get_packages(self, show):
-        """Return list of Distributions"""
+        """
+        Return list of Distributions filtered by active status or all
+
+        @param show: Type of package(s) to show; active, non-active or all
+        @type show: string: "active", "non-active", "all"
+
+        @returns: list of pkg_resources Distribution objects
+        """
+
 
         if show == 'nonactive' or show == "all":
             all_packages = []
@@ -82,24 +128,41 @@ class Distributions:
             return self.working_set
 
     def case_sensitive_name(self, package_name):
-        """Return case-sensitive package name given any-case package name"""
+        """
+        Return case-sensitive package name given any-case package name
+
+        @param project_name: PyPI project name
+        @type project_name: string
+        
+        """
         if len(self.environment[package_name]):
             return self.environment[package_name][0].project_name
 
     def get_highest_installed(self, project_name):
-        """Return highest version of installed package"""
-        #http://tools.assembla.com/yolk/ticket/17
-        #try:
-        #    return pkg_resources.require(project_name)[0].version
-        #except pkg_resources.DistributionNotFound:
-        #    Do something like:
-        #    return "Error: Possibly corrupt egg."
+        """
+        Return highest version of installed package
+
+        @param project_name: PyPI project name
+        @type project_name: string
+
+        @return: string of highest installed version
+        
+        """
         return self.environment[project_name][0].version
 
 
 def get_highest_version(versions):
-    """Given list of versions returns highest available version for a package"""
-    #Used to sort versions returned from PyPI
+    """
+    Returns highest available version for a package in a list of versions
+    Uses pkg_resources to parse the versions
+
+    @param versions: List of PyPI package versions
+    @type versions: List of strings
+
+    @returns: string of a PyPI package version
+    
+    
+    """
     sorted_versions = []
     for ver in versions:
         sorted_versions.append((pkg_resources.parse_version(ver), ver))
